.. autoXAS documentation master file

Welcome to the autoXAS documentation!
===========================================
This documentation provides an overview of the autoXAS package, including installation instructions and API details.

.. toctree::
   :maxdepth: 2
   :caption: Contents:

   readme_link
   source/modules
   




..   Indices and tables
   ==================

   * :ref:`genindex`
   * :ref:`modindex`
   * :ref:`search`